/**************************************************************************
 |                                                                         
 |                    STATA SETUP FILE FOR ICPSR 08655
 |        SURVEY OF CITY COUNCIL MEMBERS IN LARGE AMERICAN CITIES,
 |                                  1982
 |
 |
 | NOTE: This setup file was produced solely from the study documentation,
 | independent of the data.
 |
 |  Please edit this file as instructed below.
 |  To execute, start Stata, change to the directory containing:
 |       - this do file
 |       - the ASCII data file
 |       - the dictionary file
 |
 |  Then execute the do file (e.g., do 08655-0001-statasetup.do)
 |
 **************************************************************************/

set mem 6m  /* Allocating 6 megabyte(s) of RAM for Stata SE to read the
                 data file into memory. */


set more off  /* This prevents the Stata output viewer from pausing the
                 process */

/****************************************************

Section 1: File Specifications
   This section assigns local macros to the necessary files.
   Please edit:
        "data-filename" ==> The name of data file downloaded from ICPSR
        "dictionary-filename" ==> The name of the dictionary file downloaded.
        "stata-datafile" ==> The name you wish to call your Stata data file.

   Note:  We assume that the raw data, dictionary, and setup (this do file) all
          reside in the same directory (or folder).  If that is not the case
          you will need to include paths as well as filenames in the macros.

********************************************************/

local raw_data "C:\Users\christenson.24\Desktop\ICPSR_08655\DS0001\08655-0001-Data-card_image.txt"
local dict "C:\Users\christenson.24\Desktop\ICPSR_08655\DS0001\08655-0001-Setup.dct"
local outfile "C:\Users\christenson.24\Desktop\ICPSR_08655\DS0001\council.dta"

/********************************************************

Section 2: Infile Command

This section reads the raw data into Stata format.  If Section 1 was defined
properly, there should be no reason to modify this section.  These macros
should inflate automatically.

**********************************************************/

infile using `dict', using (`raw_data') clear


/*********************************************************

Section 3: Value Label Definitions
This section defines labels for the individual values of each variable.
We suggest that users do not modify this section.

**********************************************************/


label data "Survey of City Council Members in Large American Cities, 1982"

#delimit ;
label define VAR02     1 "VERY IMPORTANT" 2 "SOMEWHAT IMPORTANT"
                       3 "NOT VERY IMPORTANT" ;
label define VAR03     2 "VERY IMPORTANT" 3 "SOMEWHAT IMPORTANT"
                       4 "NOT VERY IMPORTANT" ;
label define VAR04     3 "VERY IMPORTANT" 4 "SOMEWHAT IMPORTANT"
                       5 "NOT VERY IMPORTANT" ;
label define VAR05     4 "VERY IMPORTANT" 5 "SOMEWHAT IMPORTANT"
                       6 "NOT VERY IMPORTANT" ;
label define VAR06     5 "VERY IMPORTANT" 6 "SOMEWHAT IMPORTANT"
                       7 "NOT VERY IMPORTANT" ;
label define VAR07     6 "VERY IMPORTANT" 7 "SOMEWHAT IMPORTANT"
                       8 "NOT VERY IMPORTANT" ;
label define VAR08     7 "VERY IMPORTANT" 8 "SOMEWHAT IMPORTANT"
                       9 "NOT VERY IMPORTANT" ;
label define VAR09     8 "VERY IMPORTANT" 9 "SOMEWHAT IMPORTANT"
                       10 "NOT VERY IMPORTANT" ;
label define VAR10     9 "VERY IMPORTANT" 10 "SOMEWHAT IMPORTANT"
                       11 "NOT VERY IMPORTANT" ;
label define VAR11     10 "VERY IMPORTANT" 11 "SOMEWHAT IMPORTANT"
                       12 "NOT VERY IMPORTANT" ;
label define VAR12     11 "VERY IMPORTANT" 12 "SOMEWHAT IMPORTANT"
                       13 "NOT VERY IMPORTANT" ;
label define VAR13     12 "VERY IMPORTANT" 13 "SOMEWHAT IMPORTANT"
                       14 "NOT VERY IMPORTANT" ;
label define VAR14     13 "VERY IMPORTANT" 14 "SOMEWHAT IMPORTANT"
                       15 "NOT VERY IMPORTANT" ;
label define VAR15     14 "VERY IMPORTANT" 15 "SOMEWHAT IMPORTANT"
                       16 "NOT VERY IMPORTANT" ;
label define VAR16     15 "VERY IMPORTANT" 16 "SOMEWHAT IMPORTANT"
                       17 "NOT VERY IMPORTANT" ;
label define VAR17     16 "VERY IMPORTANT" 17 "SOMEWHAT IMPORTANT"
                       18 "NOT VERY IMPORTANT" ;
label define VAR18     1 "NO, NO REAL CLEAVAGES ON COUNCIL"
                       2 "YES, SOME CLEAVAGES NOT VERY STRONG"
                       3 "YES, SHARP CLEAVAGES WITHIN COUNCIL" 9 "MISSING" ;
label define VAR19     1 "TAX CUTTERS VS. OPPONENTS"
                       2 "BUSINESS VS. NEIGHBORHOODS"
                       3 "DEMOCRATS VS. REPUBLICANS"
                       4 "ONE AREA OF CITY VS. ANOTHER"
                       5 "WHITES/ANGLOS VS. OTHERS"
                       6 "THE POLITICAL MACHINE VS. REFORMERS"
                       7 "LIBERALS VS. CONSERVATIVES"
                       8 "DEVELOPMENT INTERESTS VS. OTHERS"
                       9 "BUSINESS VS. LABOR" 10 "OTHER" 99 "MISSING/NA" ;
label define VAR20     1 "TAX CUTTERS VS. OPPONENTS"
                       2 "BUSINESS VS. NEIGHBORHOODS"
                       3 "DEMOCRATS VS. REPUBLICANS"
                       4 "ONE AREA OF CITY VS. ANOTHER"
                       5 "WHITES/ANGLOS VS. OTHERS"
                       6 "THE POLITICAL MACHINE VS. REFORMERS"
                       7 "LIBERALS VS. CONSERVATIVES"
                       8 "DEVELOPMENT INTERESTS VS. OTHERS"
                       9 "BUSINESS VS. LABOR" 10 "OTHER" 99 "MISSING/NA" ;
label define VAR21     1 "TAX CUTTERS VS. OPPONENTS"
                       2 "BUSINESS VS. NEIGHBORHOODS"
                       3 "DEMOCRATS VS. REPUBLICANS"
                       4 "ONE AREA OF CITY VS. ANOTHER"
                       5 "WHITES/ANGLOS VS. OTHERS"
                       6 "THE POLITICAL MACHINE VS. REFORMERS"
                       7 "LIBERALS VS. CONSERVATIVES"
                       8 "DEVELOPMENT INTERESTS VS. OTHERS"
                       9 "BUSINESS VS. LABOR" 10 "OTHER" 99 "MISSING/NA" ;
label define VAR22     1 "OVER 75 PERCENT" 2 "50 TO 74 PERCENT"
                       3 "25 TO 49 PERCENT" 4 "FEWER THAN 25 PERCENT"
                       9 "MISSING" ;
label define VAR23     1 "INCREASED" 2 "STAYED ABOUT THE SAME" 3 "DECREASED"
                       4 "NO CUTBACKS OR STRESSES" 9 "MISSING" ;
label define VAR24     99 "MISSING" ;
label define VAR25     99 "MISSING" ;
label define VAR26     1 "PRIMARILY CONCERNED W/ISSUE POSITIONS"
                       2 "SERVICE & POSITIONS EQUALLY IMPORTANT"
                       3 "PRIMAR CONCERND W/SERVICNG THEIR NEEDS" 9 "MISSING" ;
label define VAR27     1 "ONE" 2 "TWO" 3 "THREE" 4 "FOUR" 5 "FIVE" 6 "SIX"
                       7 "SEVEN" 8 "EIGHT" 9 "NINE" 10 "TEN" 11 "ELEVEN"
                       12 "TWELVE" 13 "THIRTEEN OR MORE" 99 "MISSING" ;
label define VAR28     1 "I SCHEDULE NO REGULAR MEETINGS"
                       2 "SCHEDULE 1 OR MORE MEETINGS EACH MONTH"
                       3 "SCHEDULE REGULAR MEEINGS, <1 A MONTH" 9 "MISSING" ;
label define VAR32     1 "VERY CONSERVATIVE" 2 "CONSERVATIVE"
                       3 "SLIGHTLY CONSERVATIVE" 4 "MIDDLE OF THE ROAD"
                       5 "SLIGHTLY LIBERAL" 6 "LIBERAL" 7 "VERY LIBERAL"
                       9 "MISSING" ;
label define VAR33     1 "CITY NOT FACED W/FISCAL PROBLEMS"
                       2 "BUDGET TIGHT&MAY MAKE CUTS IN SERVICES"
                       3 "BUDGET VERY TIGHT & SERIOUS CUTS MADE" 9 "MISSING" ;
label define VAR34     1 "ELECTED BY VOTERS ON MAYORAL BALLOT"
                       2 "CHOSEN BY COUNCIL"
                       3 "COUNCIL MEMBER RECEIVING MOST VOTES" 9 "MISSING" ;
label define VAR35     1 "YES" 2 "NO" 9 "MISSING" ;
label define VAR36     999 "MISSING" ;
label define VAR37     1 "STRONGLY AGREE" 2 "AGREE" 3 "NEUTRAL" 4 "DISAGREE"
                       5 "STRONGLY DISAGREE" 9 "MISSING" ;
label define VAR38     1 "STRONGLY AGREE" 2 "AGREE" 3 "NEUTRAL" 4 "DISAGREE"
                       5 "STRONGLY DISAGREE" 9 "MISSING" ;
label define VAR39     1 "STRONGLY AGREE" 2 "AGREE" 3 "NEUTRAL" 4 "DISAGREE"
                       5 "STRONGLY DISAGREE" 9 "MISSING" ;
label define VAR40     1 "STRONGLY AGREE" 2 "AGREE" 3 "NEUTRAL" 4 "DISAGREE"
                       5 "STRONGLY DISAGREE" 9 "MISSING" ;
label define VAR41     1 "STRONGLY AGREE" 2 "AGREE" 3 "NEUTRAL" 4 "DISAGREE"
                       5 "STRONGLY DISAGREE" 9 "MISSING" ;
label define VAR42     1 "STRONGLY AGREE" 2 "AGREE" 3 "NEUTRAL" 4 "DISAGREE"
                       5 "STRONGLY DISAGREE" 9 "MISSING" ;
label define VAR43     1 "STRONGLY AGREE" 2 "AGREE" 3 "NEUTRAL" 4 "DISAGREE"
                       5 "STRONGLY DISAGREE" 9 "MISSING" ;
label define VAR44     1 "STRONGLY REPUBLICAN" 2 "REPUBLICAN" 3 "COMPETITIVE"
                       4 "DEMOCRAT" 5 "STRONGLY DEMOCRAT" 9 "MISSING" ;
label define VAR45     1 "VERY IMPORTANT" 2 "SOMEWHAT IMPORTANT"
                       3 "NOT VERY IMPORTANT" ;
label define VAR46     1 "VERY IMPORTANT" 2 "SOMEWHAT IMPORTANT"
                       3 "NOT VERY IMPORTANT" ;
label define VAR47     1 "VERY IMPORTANT" 2 "SOMEWHAT IMPORTANT"
                       3 "NOT VERY IMPORTANT" ;
label define VAR48     1 "VERY IMPORTANT" 2 "SOMEWHAT IMPORTANT"
                       3 "NOT VERY IMPORTANT" ;
label define VAR49     1 "VERY IMPORTANT" 2 "SOMEWHAT IMPORTANT"
                       3 "NOT VERY IMPORTANT" ;
label define VAR50     1 "VERY IMPORTANT" 2 "SOMEWHAT IMPORTANT"
                       3 "NOT VERY IMPORTANT" ;
label define VAR51     1 "VERY IMPORTANT" 2 "SOMEWHAT IMPORTANT"
                       3 "NOT VERY IMPORTANT" ;
label define VAR52     1 "AT-LARGE" 2 "BY DISTRICT OR WARD"
                       3 "SOME AT-LARGE, SOME DISTRICT" 9 "MISSING" ;
label define VAR53     1 "AT-LARGE WITH DISTRICT NOMINATION" 2 "AT-LARGE"
                       3 "MIXED -- BY DISTRICT" 4 "MIXED -- AT-LARGE"
                       9 "MISSING OR CODED '2' TO QUESTION 20" ;
label define VAR54     1 "YES, CONFLICT ON MANY ISSUES"
                       2 "YES, CONFLICT ON SOME ISSUES"
                       3 "NO,NOT MUCH DIVISION ALONG THESE LINES"
                       9 "MISSING OR CODED '1' OR '2' TO QUES 20" ;
label define VAR55     1 "NONPARTISAN" 2 "PARTISAN" 9 "MISSING" ;
label define VAR56     1 "VERY ACTIVE" 2 "SOMEWHAT ACTIVE"
                       3 "NOT ACTIVE AT ALL" 9 "MISSING" ;
label define VAR57     0 "I WAS UNOPPOSED" 1 "IT WAS A CLOSE CONTEST"
                       2 "I WON BY A MODERATE MARGIN"
                       3 "I WON BY A LARGE MARGIN" 9 "MISSING" ;
label define VAR58     1 "VERY IMPORTANT" 2 "SOMEWHAT IMPORTANT"
                       3 "NOT VERY IMPORTANT" ;
label define VAR59     1 "VERY IMPORTANT" 2 "SOMEWHAT IMPORTANT"
                       3 "NOT VERY IMPORTANT" ;
label define VAR60     1 "VERY IMPORTANT" 2 "SOMEWHAT IMPORTANT"
                       3 "NOT VERY IMPORTANT" ;
label define VAR61     1 "VERY IMPORTANT" 2 "SOMEWHAT IMPORTANT"
                       3 "NOT VERY IMPORTANT" ;
label define VAR62     1 "VERY IMPORTANT" 2 "SOMEWHAT IMPORTANT"
                       3 "NOT VERY IMPORTANT" ;
label define VAR63     1 "VERY IMPORTANT" 2 "SOMEWHAT IMPORTANT"
                       3 "NOT VERY IMPORTANT" ;
label define VAR64     1 "MALE" 2 "FEMALE" 9 "MISSING" ;
label define VAR65     0 "WHITE/NON-BLACK" 1 "BLACK" ;
label define VAR66     99 "MISSING" ;
label define VAR67     99 "MISSING" ;
label define VAR68     1 "PROTESTANT" 2 "CATHOLIC" 3 "MORMON" 4 "JEWISH"
                       5 "OTHER OR NONE" 9 "MISSING" ;
label define VAR69     1 "LESS THAN $15,000" 2 "$15,000 TO $24,999"
                       3 "$25,000 TO $34,999" 4 "$35,000 TO $44,999"
                       5 "$45,000 AND OVER" 9 "MISSING" ;
label define VAR70     1 "STRONG DEMOCRAT" 2 "WEAK DEMOCRAT"
                       3 "INDEPENDENT/LEANING DEMOCRAT" 4 "INDEPENDENT"
                       5 "INDEPENDENT/LEANING REPUBLICAN" 6 "WEAK REPUBLICAN"
                       7 "STRONG REPUBLICAN" 9 "MISSING OR OTHER" ;
label define VAR71     1 "OWNER OF A BUSINESS"
                       2 "MANAGER OR WHITE COLLAR WORKER"
                       3 "BLUE COLLAR WORKER"
                       4 "LAWYER OR OTHER PROFESSIONAL" 5 "HOMEMAKER"
                       6 "STUDENT" 7 "RETIRED" 8 "FULL TIME COUNCIL MEMBER"
                       9 "MISSING OR OTHER" ;
label define VAR72     1 "HIGH SCHOOL OR LESS"
                       2 "POST-HIGH SCHOOL TECHNICAL TRAINING"
                       3 "SOME COLLEGE" 4 "COLLEGE GRADUATE"
                       5 "PROFESSIONAL OR GRADUATE SCHOOL"
                       9 "MISSING OR OTHER" ;
label define VAR73     1 "NORTHEAST" 2 "SOUTH" 3 "WEST" 4 "MIDWEST" ;


#delimit cr

/********************************************************************

 Section 4: Save Outfile

  This section saves out a Stata system format file.  There is no reason to
  modify it if the macros in Section 1 were specified correctly.

*********************************************************************/

save `outfile', replace

